// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_ui_components/src/core/utils/multi_color.dart';

abstract class ButtonStyle {
  const ButtonStyle({
    this.radius = 15,
    this.padding = 10,
    this.foregroundColors,
    this.backgroundColors,
    this.borderColors,
    this.stroke = 2,
    this.shadow = const BoxShadow(
      blurRadius: 30,
      offset: Offset(0, 5),
      color: Color.fromRGBO(0, 0, 0, 0.05),
    ),
  });

  /// Button radius
  final double? radius;

  /// Padding and gaps of this card
  final double? padding;

  /// Button foreground gradient colors (from left to right)
  final MultiColor? foregroundColors;
  
  /// Button background gradient colors (from left to right)
  final MultiColor? backgroundColors;

  /// Border colors (from left to right).
  final MultiColor? borderColors;

  /// Stroke of the border
  final double? stroke;

  /// Drop shadow
  final BoxShadow? shadow;

  ButtonStyle copyWith();
}
