// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';

part 'button_state.dart';

class ButtonCubit extends Cubit<ButtonState> {
  ButtonCubit() : super(const ButtonState.initial(ControlState.normal));

  FutureOr<void> onMouseEnter() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }
    emit(state.copyWith(state: ControlState.hovered));
  }

  FutureOr<void> onMouseLeave() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }

    emit(state.copyWith(state: ControlState.normal));
  }

  FutureOr<void> onFocus() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }
    emit(state.copyWith(state: ControlState.focused));
  }

  FutureOr<void> onUnfocus() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }
    emit(state.copyWith(state: ControlState.normal));
  }

  FutureOr<void> onClickDown() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }
    emit(state.copyWith(state: ControlState.tapped));
  }

  FutureOr<void> onClickUpIn() async {
    if (state.isDisabled) {
      return;
    }
    emit(state.copyWith(state: ControlState.hovered));
  }

  FutureOr<void> onClickUpOut() async {
    if (state.isDisabled) {
      return;
    }
    emit(state.copyWith(state: ControlState.normal));
  }

  FutureOr<void> disable() async {
    if (state.isFreezed) {
      return;
    }
    emit(state.copyWith(state: ControlState.disabled));
  }

  FutureOr<void> enable() async {
    if (state.isFreezed) {
      return;
    }
    emit(state.copyWith(state: ControlState.normal));
  }

  FutureOr<void> freeze() async {
    emit(state.copyWith(freezed: true));
  }

  FutureOr<void> unfreeze() async {
    emit(state.copyWith(freezed: false));
  }
}
