// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart' hide ButtonStyle;
import 'package:wyatt_component_copy_with_extension/component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/buttons/cubit/button_cubit.dart';
import 'package:wyatt_ui_kit/src/components/buttons/simple_icon_button/simple_icon_screen.dart';
import 'package:wyatt_ui_kit/src/core/mixin/export_bloc_mixin.dart';

part 'simple_icon_button.g.dart';

@ComponentCopyWithExtension()
class SimpleIconButton extends SimpleIconButtonComponent
    with $SimpleIconButtonCWMixin, ExportBloc<ButtonCubit> {
  SimpleIconButton({
    super.icon,
    super.disabledStyle,
    super.normalStyle,
    super.hoveredStyle,
    super.focusedStyle,
    super.tappedStyle,
    super.selectedStyle,
    super.onPressed,
    super.key,
  });

  final ButtonCubit _cubit = ButtonCubit();

  @override
  ButtonCubit get bloc => _cubit;

  @override
  SimpleIconButtonStyle? get disabledStyle =>
      super.disabledStyle as SimpleIconButtonStyle?;

  @override
  SimpleIconButtonStyle? get normalStyle =>
      super.normalStyle as SimpleIconButtonStyle?;

  @override
  SimpleIconButtonStyle? get hoveredStyle =>
      super.hoveredStyle as SimpleIconButtonStyle?;

  @override
  SimpleIconButtonStyle? get focusedStyle =>
      super.focusedStyle as SimpleIconButtonStyle?;

  @override
  SimpleIconButtonStyle? get tappedStyle =>
      super.tappedStyle as SimpleIconButtonStyle?;

  @override
  SimpleIconButtonStyle? get selectedStyle =>
      super.selectedStyle as SimpleIconButtonStyle?;

  @override
  Widget build(BuildContext context) => exportBloc(
        child: SimpleIconButtonScreen(
          icon: icon,
          disabledStyle: disabledStyle,
          normalStyle: normalStyle,
          hoveredStyle: hoveredStyle,
          focusedStyle: focusedStyle,
          tappedStyle: tappedStyle,
          selectedStyle: selectedStyle,
          onPressed: onPressed,
          key: key,
        ),
      );
}
