// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_component_copy_with_extension/component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_text.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_wrapper.dart';
import 'package:wyatt_ui_kit/src/components/gradients/gradient_text.dart';
import 'package:wyatt_ui_kit/src/core/extensions/theme_extensions.dart';

part 'quote_card.g.dart';

@ComponentCopyWithExtension()
class QuoteCard extends QuoteCardComponent with $QuoteCardCWMixin {
  const QuoteCard({
    super.avatar,
    super.name,
    super.subtitle,
    super.gradient,
    super.quote,
    super.leftQuote,
    super.rightQuote,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.minSize,
    super.maxSize,
    super.shadow,
    super.background,
    super.key,
  });

  @override
  Widget build(BuildContext context) => CardWrapper(
        background: background,
        padding: padding,
        backgroundColors: backgroundColors,
        borderColors: borderColors,
        shadow: shadow,
        maxSize: maxSize,
        minSize: minSize,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            leftQuote ??
                Align(
                  alignment: Alignment.topLeft,
                  child: GradientText(
                    '“',
                    gradient: gradient,
                    style: context.textTheme.titleLarge
                        ?.copyWith(fontWeight: FontWeight.bold),
                  ),
                ),
            if (quote != null) ...[
              CardText(
                quote!.text,
                textType: TextType.body,
                style: quote!.style,
                gradient: quote!.gradient,
              ),
            ],
            const Gap(15),
            rightQuote ??
                Align(
                  alignment: Alignment.bottomRight,
                  child: GradientText(
                    '”',
                    gradient: gradient,
                    style: context.textTheme.titleLarge
                        ?.copyWith(fontWeight: FontWeight.bold),
                  ),
                ),
            Row(
              children: [
                if (avatar != null) ...[
                  avatar!,
                  const Gap(25),
                ],
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      if (name != null) ...[
                        CardText(
                          name!.text,
                          textType: TextType.body,
                          style: name!.style,
                          gradient: name!.gradient,
                        ),
                      ],
                      if (subtitle != null) ...[
                        CardText(
                          subtitle!.text,
                          textType: TextType.subtitle,
                          style: subtitle!.style,
                          gradient: subtitle!.gradient,
                        ),
                      ],
                    ],
                  ),
                )
              ],
            ),
          ],
        ),
      );
}
